Tropical Cyclones Detection (CMCC)
==================================

The code is adapted from the CMCC use case's
`repository <https://github.com/CMCC-Foundation/ml-tropical-cyclones-detection>`_ and refers
to a TensorFLow implementation.
To know more on the interTwin tropical cyclones detection use case and its DT, please 
visit the published deliverables, `D4.1 <https://zenodo.org/records/10417135>`_, 
`D7.1 <https://zenodo.org/records/10417158>`_ and 
`D7.3 <https://zenodo.org/records/10224252>`_.
You can find the relevant code in the
`use case's folder on Github <https://github.com/interTwin-eu/itwinai/tree/main/use-cases/cyclones>`_,
or by consulting the use case's README: 

.. include:: ../../use-cases/cyclones/README.md
   :parser: myst_parser.sphinx_
   :start-line: 2
